@@ -1,7 +1,7 @@
 import numba as nb
 import numpy as np
-from ._special import stdtr, stdtrit
-from math import lgamma
+from ._special import stdtr as _cdf, stdtrit as _ppf
+from math import lgamma as _lgamma
 
 _signatures = [
     nb.float32(nb.float32, nb.float32, nb.float32, nb.float32),
@@ -16,7 +16,7 @@ def pdf(x, df, mu, sigma):
     """
     z = (x - mu) / sigma
     k = 0.5 * (df + 1)
-    p = np.exp(lgamma(k) - lgamma(0.5 * df))
+    p = np.exp(_lgamma(k) - _lgamma(0.5 * df))
     p /= np.sqrt(df * np.pi) * (1 + (z ** 2) / df) ** k
     return p / sigma
 
@@ -27,7 +27,7 @@ def cdf(x, df, mu, sigma):
     Evaluate cumulative distribution function of student's distribution.
     """
     z = (x - mu) / sigma
-    return stdtr(df, z)
+    return _cdf(df, z)
 
 
 @nb.vectorize(_signatures)
@@ -39,5 +39,5 @@ def ppf(p, df, mu, sigma):
         return -np.inf
     elif p == 1:
         return np.inf
-    z = stdtrit(df, p)
+    z = _ppf(df, p)
     return sigma * z + mu
